class Constants:
    USER_AGENT = (
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/605.1.15"
        " (KHTML, like Gecko) Version/14.0.3 Safari/605.1.15"
    )
    BASE_URL = "https://www.ikea.com"
    LANGUAGE_CODE: str = "ru"
    COUNTRY_CODE: str = "ru"


class Secrets:
    cart_x_client_id = "66e4684a-dbcb-499c-8639-a72fa50ac0c3"
    item_ingka_x_client_id = "c4faceb6-0598-44a2-bae4-2c02f4019d06"
    item_iows_consumer = "MAMMUT#ShoppingCart"
    item_iows_contract = "37249"
    purchases_x_client_id = "af2525c3-1779-49be-8d7d-adf32cac1934"
    purchases_checkout_x_client_id = "6a38e438-0bbb-4d4f-bc55-eb314c2e8e23"
    auth_guest_token_x_client_id = "e026b58d-dd69-425f-a67f-1e9a5087b87b"  # nosec
    auth_guest_token_x_client_secret = (  # nosec
        "cP0vA4hJ4gD8kO3vX3fP2nE6xT7pT3oH0gC5gX6yB4cY7oR5mB"
    )
